summaryrefslogtreecommitdiffstats
path: root/crawl-ref
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref')
-rw-r--r--crawl-ref/source/files.cc6
1 files changed, 4 insertions, 2 deletions
diff --git a/crawl-ref/source/files.cc b/crawl-ref/source/files.cc
index 7ea4991c0d..bedfa97b1f 100644
--- a/crawl-ref/source/files.cc
+++ b/crawl-ref/source/files.cc
@@ -741,8 +741,10 @@ void load( unsigned char stair_taken, int load_mode, bool was_a_labyrinth,
if (you.level_type == LEVEL_PANDEMONIUM)
generate_random_demon();
- else if (you.your_level > 1 && one_chance_in(3))
- load_ghost(); // no ghosts in Pan
+ else if (you.your_level > 1
+ && one_chance_in(3)
+ && you.level_type != LEVEL_LABYRINTH)
+ load_ghost(); // no ghosts in Pan or Labyrinth
}
else
{